==> nextcloud-13.0.1.tgz: nextcloud/apps/gallery/l10n/pt_PT.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Ocorreu um problema ao ler os ficheiros deste álbum",
    "Aborting preview. Could not find the file" : "A abortar a pré-visualização. Não foi possível encontrar o ficheiro",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", alvo já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "Could not load the description" : "Não foi possível carregar a descrição",
    "Could not load the description: " : "Não foi possível carregar a descrição:",
    "Copyright" : "Direitos de Autor",
    "Could not load the copyright notice: " : "Não foi possível carregar a notificação dos direitos de autor:",
    "Copyright notice" : "Notificação dos direitos de autor",
    "Link to copyright document" : "Hiperligação para o documento dos direitos de autor",
    "This application may not work properly on your browser." : "Esta aplicação poderá não funcionar corretamente no seu navegador.",
    "For an improved experience, please install one of the following alternatives" : "Para uma experiência melhorada, por favor, instale uma das seguintes alternativas",
    "Your browser is not supported!" : "O seu navegador não é suportado!",
    "please install one of the following alternatives" : "por favor, instale uma das seguintes alternativas",
    "Album cannot be shown" : "O álbum não pode ser apresentado",
    "No media files found" : "Não foram encontrados quaisquer ficheiros multimédia",
    "Upload new files via drag and drop or by using the [+] button above" : "Envie ficheiros novos através da técnica de arrastar e largar ou usando o botão [+] acima",
    "Configuration error" : "Erro de configuração",
    "New" : "Novo",
    "Error loading slideshow template" : "Ocorreu um erro a carregar o modelo de diapositivos",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Erro!</strong> Não foi possível gerar uma pré-visualização deste ficheiro.<br>Por favor siga para o próximo diapositivo enquanto removemos esta imagem da apresentação",
    "Next" : "Seguinte",
    "Play" : "Reproduzir",
    "Pause" : "Pausar",
    "Previous" : "Anterior",
    "Close" : "Fechar",
    "Download" : "Descarregar",
    "Toggle background" : "Alternar fundo",
    "Delete" : "Eliminar ",
    "Share" : "Partilhar",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "Upload" : "Carregar",
    "Error" : "Erro",
    "Error while sharing" : "Erro ao partilhar",
    "Error while unsharing" : "Erro ao remover a partilha",
    "Error while changing permissions" : "Erro ao mudar permissões",
    "Shared with you and the group {group} by {owner}" : "Partilhado consigo e com o grupo {group} por {owner}",
    "Shared with you by {owner}" : "Partilhado consigo por {owner}",
    "Share with users or groups …" : "Partilhar com utilizadores ou grupos...",
    "Share with users, groups or remote users …" : "Partilhar com utilizadores, grupos ou utilizadores remotos...",
    "Share link" : "Partilhar hiperligação",
    "The public link will expire no later than {days} days after it is created" : "O link público expira, o mais tardar {days} dias após sua criação",
    "Link" : "Hiperligação",
    "Password protect" : "Proteger com Palavra-passe",
    "Password" : "Senha",
    "Choose a password for the public link" : "Escolha a senha para a hiperligação pública",
    "Allow editing" : "Permitir edição",
    "Email link to person" : "Enviar a hiperligação para a pessoa",
    "Send" : "Enviar",
    "Set expiration date" : "Definir a data de expiração",
    "Expiration" : "Expira em",
    "Expiration date" : "Data de expiração",
    "An error occured. Please try again" : "Ocorreu um erro. Por favor, tente de novo",
    "Adding user..." : "A adicionar o utilizador ...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "Não é permitido partilhar de novo",
    "Error while retrieving shares" : "Erro ao obter partilhas",
    "Unshare" : "Cancelar partilha",
    "notify by email" : "Notificar por correio eletrónico",
    "can share" : "pode partilhar",
    "can edit" : "pode editar",
    "access control" : "controlo de acesso",
    "create" : "criar",
    "change" : "alterar",
    "delete" : "eliminar",
    "Password protected" : "Protegido com Palavra-passe",
    "Error unsetting expiration date" : "Erro ao retirar a data de expiração",
    "Error setting expiration date" : "Erro ao aplicar a data de expiração",
    "Email sent" : "Mensagem enviada",
    "Warning" : "Aviso",
    "This share is password-protected" : "Esta partilha está protegida por senha",
    "The password is wrong. Try again." : "A senha está errada. Por favor, tente de novo.",
    "Sort by name" : "Ordenar por nome",
    "Sort by date" : "Ordenar por data",
    "Cancel upload" : "Cancelar o envio",
    "Album information" : "Informação do álbum",
    "File list" : "Lista de Ficheiros",
    "Sorry, this file could not be found." : "Desculpe, não foi possível encontrar este ficheiro.",
    "Reasons might be:" : "As razões poderão ser:",
    "the wrong file ID was provided" : "foi fornecida a Id. de ficheiro errada",
    "the file was removed" : "o ficheiro foi removido",
    "the file is corrupt" : "o ficheiro está corrompido",
    "the encryption key is missing" : "a chave de encriptação está em falta",
    "Here is the error message returned by the server: " : "Aqui tem a mensagem de erro devolvida pelo servidor:",
    "Sorry, but the server could not fulfill your request." : "Desculpe, o servidor não conseguiu completar o seu pedido.",
    "Possible reasons for the problem:" : "Razões possíveis para o problema:",
    "a conflicting app was installed" : "foi instalada uma app conflituosa",
    "a required component is missing or was disconnected" : "está em falta um componente necessário ou foi desligado",
    "the filesystem is not readable" : "o sistema de ficheiros não é legível",
    "Sorry, this link doesn't seem to work anymore." : "Desculpe, esta hiperligação parece que já não funciona.",
    "the item was removed" : "o item foi removido",
    "the link has expired" : "a hiperligação expirou",
    "sharing is disabled" : "a partilha está desativada",
    "For more information, please ask the person who has sent you this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
    "Picture view" : "Visualização da Imagem",
    "Gallery view" : "Visualização da galeria",
    "Sending ..." : "A enviar..."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/gallery/l10n/pt_PT.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Ocorreu um problema ao ler os ficheiros deste álbum",
    "Aborting preview. Could not find the file" : "A abortar a pré-visualização. Não foi possível encontrar o ficheiro",
    "Could not move \"{file}\", target exists" : "Não foi possível mover \"{file}\", alvo já existe",
    "Could not move \"{file}\"" : "Não foi possível mover \"{file}\"",
    "Could not load the description" : "Não foi possível carregar a descrição",
    "Could not load the description: " : "Não foi possível carregar a descrição:",
    "Copyright" : "Direitos de Autor",
    "Could not load the copyright notice: " : "Não foi possível carregar a notificação dos direitos de autor:",
    "Copyright notice" : "Notificação dos direitos de autor",
    "Link to copyright document" : "Hiperligação para o documento dos direitos de autor",
    "This application may not work properly on your browser." : "Esta aplicação poderá não funcionar corretamente no seu navegador.",
    "For an improved experience, please install one of the following alternatives" : "Para uma experiência melhorada, por favor, instale uma das seguintes alternativas",
    "Your browser is not supported!" : "O seu navegador não é suportado!",
    "please install one of the following alternatives" : "por favor, instale uma das seguintes alternativas",
    "Album cannot be shown" : "O álbum não pode ser apresentado",
    "No media files found" : "Não foram encontrados quaisquer ficheiros multimédia",
    "Upload new files via drag and drop or by using the [+] button above" : "Envie ficheiros novos através da técnica de arrastar e largar ou usando o botão [+] acima",
    "Configuration error" : "Erro de configuração",
    "New" : "Novo",
    "Error loading slideshow template" : "Ocorreu um erro a carregar o modelo de diapositivos",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Erro!</strong> Não foi possível gerar uma pré-visualização deste ficheiro.<br>Por favor, vá para o próximo diapositivo enquanto nós removemos esta imagem do diaporama",
    "Next" : "Seguinte",
    "Play" : "Reproduzir",
    "Pause" : "Pausar",
    "Previous" : "Anterior",
    "Close" : "Fechar",
    "Download" : "Transferir",
    "Toggle background" : "Alternar fundo",
    "Delete" : "Eliminar ",
    "Share" : "Partilhar",
    "Could not create file \"{file}\" because it already exists" : "Não foi possível criar o ficheiro \"{file}\", porque este já existe",
    "Could not create file \"{file}\"" : "Não foi possível criar o ficheiro \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
    "File name cannot be empty." : "O nome do ficheiro não pode estar em branco.",
    "Upload" : "Carregar",
    "Error" : "Erro",
    "Error while sharing" : "Erro ao partilhar",
    "Error while unsharing" : "Erro ao remover a partilha",
    "Error while changing permissions" : "Erro ao mudar permissões",
    "Shared with you and the group {group} by {owner}" : "Partilhado consigo e com o grupo {group} por {owner}",
    "Shared with you by {owner}" : "Partilhado consigo por {owner}",
    "Share with users or groups …" : "Partilhar com utilizadores ou grupos...",
    "Share with users, groups or remote users …" : "Partilhar com utilizadores, grupos ou utilizadores remotos...",
    "Share link" : "Partilhar hiperligação",
    "The public link will expire no later than {days} days after it is created" : "O link público expira, o mais tardar {days} dias após sua criação",
    "Link" : "Hiperligação",
    "Password protect" : "Proteger com Palavra-passe",
    "Password" : "Senha",
    "Choose a password for the public link" : "Escolha a senha para a hiperligação pública",
    "Allow editing" : "Permitir edição",
    "Email link to person" : "Enviar a hiperligação para a pessoa",
    "Send" : "Enviar",
    "Set expiration date" : "Definir a data de expiração",
    "Expiration" : "Expira em",
    "Expiration date" : "Data de expiração",
    "Adding user..." : "A adicionar o utilizador ...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "Não é permitido partilhar de novo",
    "Error while retrieving shares" : "Erro ao obter partilhas",
    "Unshare" : "Cancelar partilha",
    "notify by email" : "Notificar por correio eletrónico",
    "can share" : "pode partilhar",
    "can edit" : "pode editar",
    "access control" : "controlo de acesso",
    "create" : "criar",
    "change" : "alterar",
    "delete" : "eliminar",
    "Password protected" : "Protegido com Palavra-passe",
    "Error unsetting expiration date" : "Erro ao retirar a data de expiração",
    "Error setting expiration date" : "Erro ao aplicar a data de expiração",
    "Email sent" : "Mensagem enviada",
    "Warning" : "Aviso",
    "This share is password-protected" : "Esta partilha está protegida por senha",
    "The password is wrong. Try again." : "A senha está errada. Por favor, tente de novo.",
    "Sort by name" : "Ordenar por nome",
    "Sort by date" : "Ordenar por data",
    "Cancel upload" : "Cancelar o envio",
    "Album information" : "Informação do álbum",
    "File list" : "Lista de Ficheiros",
    "Sorry, this file could not be found." : "Desculpe, não foi possível encontrar este ficheiro.",
    "Reasons might be:" : "As razões poderão ser:",
    "the wrong file ID was provided" : "foi fornecida a Id. de ficheiro errada",
    "the file was removed" : "o ficheiro foi removido",
    "the file is corrupt" : "o ficheiro está corrompido",
    "the encryption key is missing" : "a chave de encriptação está em falta",
    "Here is the error message returned by the server: " : "Aqui tem a mensagem de erro devolvida pelo servidor:",
    "Sorry, but the server could not fulfill your request." : "Desculpe, o servidor não conseguiu completar o seu pedido.",
    "Possible reasons for the problem:" : "Razões possíveis para o problema:",
    "a conflicting app was installed" : "foi instalada uma app conflituosa",
    "a required component is missing or was disconnected" : "está em falta um componente necessário ou foi desligado",
    "the filesystem is not readable" : "o sistema de ficheiros não é legível",
    "Sorry, this link doesn't seem to work anymore." : "Desculpe, esta hiperligação parece que já não funciona.",
    "the item was removed" : "o item foi removido",
    "the link has expired" : "a hiperligação expirou",
    "sharing is disabled" : "a partilha está desativada",
    "For more information, please ask the person who has sent you this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
    "Picture view" : "Visualização da Imagem",
    "Gallery view" : "Visualização da galeria",
    "An error occured. Please try again" : "Ocorreu um erro. Por favor, tente de novo",
    "Sending ..." : "A enviar..."
},
"nplurals=2; plural=(n != 1);");
